@@ -10,7 +10,7 @@ use Mojo::Util qw(steady_time);
 use Mojolicious;
 use POSIX qw(WNOHANG);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # This should be considered internal for now
 our $MOJODCTL = do {
@@ -191,7 +191,7 @@ sub _spawn ($self, $app) {
   $ENV{MOJODCTL_HEARTBEAT_FD}       = fileno $self->{worker_write};
   $ENV{MOJODCTL_HEARTBEAT_INTERVAL} = $self->heartbeat_interval;
 
-  my @args;
+  my (@urls, @args) = @{$self->listen};
   for my $fh ($self->{worker_write}, @{$self->_listen_handles}) {
 
     # Remove close-on-exec flag
@@ -200,7 +200,7 @@ sub _spawn ($self, $app) {
     fcntl $fh, F_SETFD, $flags & ~FD_CLOEXEC or die "fcntl F_SETFD: $!";
 
     next if $fh eq $self->{worker_write};
-    my $url = Mojo::URL->new('http://127.0.0.1');
+    my $url = Mojo::URL->new(shift @urls);
     $url->query->param(fd => fileno $fh);
     push @args, -l => $url->to_string;
   }
@@ -290,16 +290,6 @@ code run, while new processes are deployed.
 Note that L<Mojo::Server::DaemonControl> is currently EXPERIMENTAL and it has
 not been tested in production yet. Feedback is more than welcome.
 
-=head1 ENVIRONMENT VARIABLES
-
-Some environment variables can be set in C<systemd> service files, while other
-can be useful to be read when initializing your web server.
-
-=head2 MOJODCTL_CONTROL_CLASS
-
-This environment variable will be set to L<Mojo::Server::DaemonControl::Worker>
-inside the worker process.
-
 =head1 SIGNALS
 
 =head2 INT, TERM
@@ -340,6 +330,14 @@ appended to C<$0> to illustrate which is new and which is old.
 L<Mojo::Server::DaemonControl> inherits all attributes from
 L<Mojo::EventEmitter> and implements the following ones.
 
+=head2 cleanup
+
+  $bool = $dctl->cleanup;
+  $dctl = $dctl->cleanup(1);
+
+Set this to true and L<Mojo::Server::DaemonControl> will remove L</pid_file>
+when this object goes out of scope.
+
 =head2 graceful_timeout
 
   $timeout = $dctl->graceful_timeout;
